:orphan:


SubModule: :mod:`soma.application`
==================================

.. automodule:: soma.application
    :members:


SubModule: ``bufferandfile``
============================

.. automodule:: soma.bufferandfile
    :members:


.. _controller:

SubModule: ``controller``: Traits-based controller objects
==========================================================

Classes
-------
* :class:`soma.controller.controller.Controller`

API
---

.. automodule:: soma.controller
    :members:

.. automodule:: soma.controller.controller
    :members:


SubModule: ``debug``
====================

.. automodule:: soma.debug
    :members:


SubModule: ``fom``: File Organization Model
===========================================

.. automodule:: soma.fom
    :members:


SubModule: ``gui``
==================

The gui module should move to :mod:`soma.qt_gui`

.. automodule:: soma.gui
    :members:

.. automodule:: soma.gui.file_selection
    :members:

.. automodule:: soma.gui.icon_factory
    :members:

.. automodule:: soma.gui.trait_to_widget
    :members:

.. automodule:: soma.gui.widget_controller_creation
    :members:

.. automodule:: soma.gui.widget_factory
    :members:


SubModule: ``html``
===================

.. automodule:: soma.html
    :members:


SubModule: ``importer``
=======================

.. automodule:: soma.importer
    :members:


SubModule: ``minf``
===================

.. automodule:: soma.minf.api
    :members:


SubModule: ``notification``
===========================

.. automodule:: soma.notification
    :members:


SubModule: ``path``
===================

.. automodule:: soma.path
    :members:


SubModule: ``pyro``
===================

.. automodule:: soma.pyro
    :members:


SubModule: ``qt4gui``
=====================

.. automodule:: soma.qt4gui
    :members:

.. automodule:: soma.qt4gui.api
    :members:

``io``
------

.. automodule:: soma.qt4gui.io
    :members:

``list_tree_widgets``
---------------------

.. automodule:: soma.qt4gui.list_tree_widgets
    :members:

``qtThread``
------------

.. automodule:: soma.qt4gui.qtThread
    :members:

``rangeSlider``
---------------

.. automodule:: soma.qt4gui.rangeSlider
    :members:

``simple_table``
----------------

.. automodule:: soma.qt4gui.simple_table
    :members:

``text``
--------

.. automodule:: soma.qt4gui.text
    :members:

``timered_widgets``
-------------------

.. automodule:: soma.qt4gui.timered_widgets
    :members:


SubModule: ``qt_gui``
=====================

.. automodule:: soma.qt_gui
    :members:

qt_backend
----------

.. automodule:: soma.qt_gui.qt_backend
    :members:

widgets
-------

.. automodule:: soma.qt_gui.widgets
    :members:

.. automodule:: soma.qt_gui.widgets.file_selection_widget
    :members:

SubModule: ``singleton``
========================

.. automodule:: soma.singleton
    :members:


SubModule: ``somatime``
=======================

.. automodule:: soma.somatime
    :members:


SubModule: ``sorted_dictionary``
================================

.. automodule:: soma.sorted_dictionary
    :members:


SubModule: ``stringtools``
==========================

.. automodule:: soma.stringtools
    :members:


SubModule: ``thread_calls``
===========================

.. automodule:: soma.thread_calls
    :members:


SubModule: ``translation``
==========================

.. automodule:: soma.translation
    :members:


SubModule: ``undefined``
========================

.. automodule:: soma.undefined
    :members:


SubModule: ``utils``
====================

.. automodule:: soma.utils
    :members:


.. automodule:: soma.utils.functiontools
    :members:


SubModule: ``uuid``
===================

.. automodule:: soma.uuid
    :members:


SubModule: ``zipfile``
======================

.. automodule:: soma.zipfile
    :members:


